@@ -38,7 +38,11 @@ class TestGetKey:
 
     def test_get_invalid_key(self):
         with pytest.raises(KeyError):
-            Resource(None, data={}).Invalid_key
+            Resource(None, data={})['Invalid_key']
+
+    def test_get_invalid_attribute(self):
+        with pytest.raises(AttributeError, match=".+ 'Invalid_Attribute'"):
+            Resource(None, data={}).Invalid_Attribute
 
     def test_dig(self):
         assert Resource(None, data={
